@@ -11,7 +11,8 @@
 #' histData \tab      \tab the set of n most cited references}
 #' 
 #' is a network matrix obtained by the function \code{\link{biblioNetwork}}. 
-#' @param size is logical. If TRUE the point size of each vertex is proportional to its degree. 
+#' @param size is logical. If TRUE the point size of each vertex is proportional to its degree.
+#' @param labelsize is an integer. It indicates the label size in the plot. Default is \code{labelsize=1}
 #' @return It is a network object of the class \code{igraph}.
 #' 
 #' @examples
@@ -29,7 +30,7 @@
 #' @seealso \code{\link{biblioAnalysis}} to perform a bibliometric analysis.
 #' 
 #' @export
-histPlot<-function(histResults, size = F){
+histPlot<-function(histResults, size = F, labelsize = 1){
   
   NET=histResults$NetMatrix
   
@@ -45,14 +46,17 @@ histPlot<-function(histResults, size = F){
   # Remove loops
   bsk.network <- simplify(bsk.network, remove.multiple = T, remove.loops = T) 
   
+  
+  V(bsk.network)$color <- 'red'
+  
   # delete not linked vertices
-  bsk.network <- delete.isolates(bsk.network, mode = 'in')
+  #bsk.network <- delete.isolates(bsk.network, mode = 'in')
   
   # Choose Network layout
   l <- layout.fruchterman.reingold(bsk.network) #default
   l[,2]=histResults[[3]]$Year
   # Plot the chronological co-citation network
-  plot(bsk.network,layout = l, vertex.label.dist = 0.5, vertex.frame.color = 'black', vertex.label.color = 'black', vertex.label.font = 1, vertex.label = row.names(histResults[[3]]), vertex.label.cex = 0.7, edge.arrow.size=0.1, main="Historical co-citation network")
+  plot(bsk.network,layout = l, vertex.label.dist = 0.5, vertex.frame.color = 'black', vertex.label.color = 'darkblue', vertex.label.font = 1, vertex.label = row.names(histResults[[3]]), vertex.label.cex = labelsize, edge.arrow.size=0.1, main="Historical co-citation network")
   cat("\n Legend\n\n")
   print(histResults[[3]])
   
